//******************************************************************//
//File Name: sampleProgram.c                                        //
//Version:   2.0                                                    //
//Company:   Tri-M Engineering                                      //
//Date:      Oct. 29, 2002                                          //
//                                                                  //
//this file is used to display how to use functions declared in     //
//generalDriver.h to control following boards:                      //
//                                                                  //
//1. IR104                                                          //
//2. R104-88                                                        //
//3. R104-16DO                                                      //
//4. R104-16DI                                                      //
//5. IO104-60IN                                                     //
//******************************************************************//


#include "generalDriver.h"

//for command line input from user
char line[256];

//*******************************************************************
//Name: IR104Access
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the IR104 board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************

void IR104Access()
{
   unsigned int addr;
   unsigned int cmd;
   unsigned int relay;
   unsigned int opto;
   unsigned int value; 
   int i;


   printf ("Enter the base address(default 0x300): ");
   fgets(line, sizeof(line), stdin);
   sscanf(line, "%x", &addr);

   do
   {
      printf("----------------------------------------\n");
      printf( "1. Set relay on IR104 board\n" );
      printf( "2. Reset relay on IR104 board\n" );
      printf( "3. Read relay status on IR104 board\n" );
      printf( "4. read opto input status on IR104 board\n" );
      printf( "99. quit the operation for IR104\n");
      printf( "---------------------------------------\n");

      printf( "\n");
      printf( "Enter option: " );

      cmd = 0;
      fgets(line, sizeof(line), stdin);
      sscanf(line, "%d", &cmd);

      switch(cmd)
      {
       case 1:
           printf("\nEnter the relay number(1-20) to set: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if( IR104SetRelay(addr, relay) != 0)
	   {
              printf("===Error To Set Relay===\n");
	      return; 
	   }
	   
	   for( i = 1; i <= 20; i++)
	   {
             relay = i;
	     if( IR104RelayRead(addr, relay, &value) != 0)
	     {
	        printf("===Error To Read Relay Value===\n");
		return;
	     }
             printf( "Set relay %d, Bit value received from relay: %d\n",  relay,  value);
	   }
           break;
       case 2:
	   printf("\nEnter the relay number(1-20) to reset : ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if(IR104ResetRelay(addr, relay) != 0)
	   {
              printf("===Error To  Reset Relay===\n");
	      return;
	   }
	   
	   for( i = 1; i <= 20; i++)
	   {
             relay = i;
	     if( IR104RelayRead(addr, relay, &value) != 0)
	     {
	         printf("===Error To Read Relay Value===\n");
		 return;
	     }
             printf( "Reset relay %d, Bit value received from relay: %d\n",  relay,  value);
	   }
	   break;
       case 3:
	   printf("\nEnter the relay number(1-20) to read its value: ");

	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);

	   if(IR104RelayRead( addr, relay, &value) != 0)
	   {
              printf("===Error To Read Relay Value===\n");
	      return;
	   }
	   printf( "Bit value received from relay%d: %d\n", relay, value);
	   break;
       case 4:
	   printf("\nEnter the opto number(1-20) to read its value: ");

	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &opto);

	   if( IR104OptoRead( addr, opto, &value) != 0)
	   {
              printf( "===Error To Read Opto Value===\n");
	      return;
	   }

	   printf( "Bit value received from opto%d: %d\n", opto, value);
	   break;
      }
   } while(cmd != 99);
}


//*******************************************************************
//Name: IR104_88Access
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the IR104-88 board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************

void R104_88Access()
{
   unsigned int addr;
   unsigned int cmd;
   unsigned int relay;
   unsigned int opto;
   unsigned int value; 

   printf ("Enter the base address(default 0x240): ");
   fgets(line, sizeof(line), stdin);
   sscanf(line, "%x", &addr);

   do
   {
      printf( "---------------------------------------\n");
      printf( "1. Set relay on R104-88 board\n" );
      printf( "2. Reset relay on R104-88 board\n" );
      printf( "3. read opto input status on R104-88 board\n" );
      printf( "99. quit the operation for R104-88\n");
      printf( "---------------------------------------\n");

      printf( "\n");
      printf( "Enter option: " );
      cmd = 0;
      
      fgets(line, sizeof(line), stdin);
      sscanf(line, "%d", &cmd);

      switch(cmd)
      {
       case 1:
           printf("\nEnter the relay number(1-8) to set: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if( R104_88SetRelay(addr, relay) != 0)
	   {
              printf("===Error To  Set Relay===\n");
	      return;
	   }
           break;
       case 2:
	   printf("\nEnter the reset relay number(1-8): ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if( R104_88ResetRelay(addr, relay) != 0)
	   {
              printf("===Rrror To Reset Relay===\n");
	      return;
	   }
           break;
       case 3:
	   printf("\nEnter the opto number(1-8) to read its value: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &opto);
	   
	   if( R104_88OptoRead(addr, opto, &value) != 0)
	   {
              printf("===Error To Read Opto Value===\n");
	      return;
	   }
	   printf( "Bit value received from opto%d: %d\n", opto, value);
           break;
      }
   }while(cmd!=99);
}



//*******************************************************************
//Name: R104_16DOAccess
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the R104-16DO board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************
void R104_16DOAccess()
{
   unsigned int addr;
   unsigned int cmd;
   unsigned int relay;

   printf ("Enter the base address(default 0x260): ");
   fgets(line, sizeof(line), stdin);
   sscanf(line, "%x", &addr);

   do
   {
      printf( "---------------------------------------\n");
      printf( "1. Set relay on R104-16DO board\n" );
      printf( "2. Reset relay on R104-16DO board\n" );
      printf( "99. quit the operation for R104-16DO\n");
      printf( "---------------------------------------\n");

      printf( "\n");
      printf( "Enter option: " );
      cmd = 0;
      
      fgets(line, sizeof(line), stdin);
      sscanf(line, "%d", &cmd);

      switch(cmd)
      {
       case 1:
           printf("\nEnter the relay number(1-16) to set: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if( R104_16DOSetRelay(addr, relay) != 0)
	   {
              printf("===Error To Set Relay===\n");
	      return;
	   }
           break;
       case 2:
	   printf("\nEnter the reset relay number(1-16): ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &relay);
	   
	   if( R104_16DOResetRelay(addr, relay) != 0)
	   {
              printf("===Error To Reset Relay===\n");
	      return;
	   }
           break;
	 }
   }while(cmd!=99);
}


//*******************************************************************
//Name: R104_88DIAccess
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the R104-16DI board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************
void R104_16DIAccess()
{
   unsigned int addr;
   unsigned int cmd;
   unsigned int opto;
   unsigned int value; 

   printf ("Enter the base address(default 0x280): ");
   fgets(line, sizeof(line), stdin);
   sscanf(line, "%x", &addr);

   do
   {
      printf( "---------------------------------------\n");
      printf( "1. Read opto input status on R104-16DI board\n" );
      printf( "99. quit the operation for R104-16DI\n");
      printf( "---------------------------------------\n");

      printf( "\n");
      printf( "Enter option: " );
      cmd = 0;
      
      fgets(line, sizeof(line), stdin);
      sscanf(line, "%d", &cmd);

      switch(cmd)
      {
       case 1:
           printf("\nEnter the opto number(1-16) to read its value: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &opto);
	   
	   if( R104_16DIOptoRead(addr, opto, &value) != 0)
	   {
              printf("===Error To Read Opto Value===\n");
	      return;
	   }

	   printf( "Bit value received from opto%d: %d\n", opto, value);   		    
           break;
      }
   }while(cmd!=99);
}



//*******************************************************************
//Name: IO104_60INAccess
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the IO104-60IN board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************
void IO104_60INAccess()
{
   unsigned int addr;
   unsigned int cmd;
   unsigned int opto;
   unsigned int value; 

   printf ("Enter the base address(default 0x240): ");
   fgets(line, sizeof(line), stdin);
   sscanf(line, "%x", &addr);

   do
   {
      printf( "---------------------------------------\n");
      printf( "1. Read opto input status on IO104-60IN board\n" );
      printf( "99. quit the operation for IO104-60IN\n");
      printf( "---------------------------------------\n");

      printf( "\n");
      printf( "Enter option: " );
      cmd = 0;
      
      fgets(line, sizeof(line), stdin);
      sscanf(line, "%d", &cmd);

      switch(cmd)
      {
       case 1:
           printf("\nEnter the opto number(1-60) to read its value: ");
	   fgets(line, sizeof(line), stdin);
	   sscanf(line, "%d", &opto);
	   
	   if( IO104_60INOptoRead(addr, opto, &value) != 0)
	   {
              printf("===Error To Read Opto Value===\n");
	      return;
	   }

	   printf( "Bit value received from opto%d: %d\n", opto, value);   		    
           break;
      }
   }while(cmd!=99);
}

       
//*******************************************************************
//Name: IR104_88Access
//Parameter: None
//Return:    None
//feature:   prompt user to enter board base address and to select
//the function to operate the IR104-88 board, this function get the 
//user input for base address, the operation type, relay number and 
//opto number, they call corresponding function from driver's .o file
//*******************************************************************
void BoardAccess()
{
  int cmd;

  do
  {
    printf ( "-----------------------------------------\n" );
    printf ( "please choose the board you want to access\n" );
    printf ( "1. for IR104 board\n" );
    printf ( "2. for R104-88 board\n" );
    printf ( "3. for R104-16DO board\n" );
    printf ( "4. for R104-16DI board\n" );
    printf ( "5. for IO104-60IN board\n");
    printf ( "99. quit the process\n" );
    printf ( "------------------------------------------\n" );

    printf ("\n");
    printf ( "Enter option: ");

    fgets(line, sizeof(line), stdin);
    sscanf( line, "%d", &cmd);

    switch(cmd)
    {
    case 1:
       IR104Access();
       break;
    case 2:
       R104_88Access();
       break;
    case 3:
       R104_16DOAccess();
       break;
    case 4:
       R104_16DIAccess();
       break;
    case 5:
       IO104_60INAccess();
       break;
    }
  }while(cmd !=99);  
}

int main(int argc, char *argv[])
{
 BoardAccess();
  return 0;
}
